function [t,I_redox_n,C_slit,r,z] = dim2_zyl_final_02(d_,nAE,r_electrode_,R_electrode_,R_total_,A_eff,c_bulk_,ox_red,D_,charge,gamma_ox,gamma_red,E0_,U_,t_sim,t_record,vStepTime,dt_max,dr_max_)
% Simulation of concentration and current in a redoxcycling Sensor
%
% This script will simulate in two dimensions the transient behavior
% of the redox species when stepping the voltage from zero to E.
% The explicit differences method with zero-order current approximation
% will be used. No analyte intake and multiple sets of AE will be
% regarded in the calculation.
% The calculation is reduced to one form of the mediator, which is the
% oxidized form. Thus all concentration outputs will represent the
% concentration of the oxidzed form only.
%
% This is the calculation for cylindrical coordinates, assuming the
% geometry to be symetrical around the z axis. Thus the geometry can be
% reduced to two coordinates (r,z).
%
%
% USAGE: [t,I_redox_n,C_slit,r,z] = dim2_zyl_final_02(d,nAE,r_electrode,...
%                           R_electrode,R_total,A_eff,c_bulk,ox_red,D,...
%                           charge,gamma_ox,gamma_red,E0,U,...
%                           t_sim,t_record,vStepTime,dt_max,dr_max)
%
%   Numbers in brackets are sample configuration values.
%
%   d   .. electrode distance in m (10)
%   nAE .. number of electrode pairs (2)
%   r_electrode .. a line vector that holds the start radii of all electrodes in m ([0 600])
%   R_electrode .. a line vector that holds the end radii of all electrodes in m ([400 800])
%   R_total   .. total radius of cell in m (1200)
%   A_eff .. correction factor for effective surface area based on roughness (1.4)
%   c_bulk .. total concentration of oxidized and reduced mediator in mol/l (1e-2)
%   ox_red .. concentration factor c_ox/c_red of mediator (1000)
%   D .. diffusion coeff. of mediator in cm/s (7e-6)
%   charge .. charge transfered in electrode reaction
%   gamma_ox .. activity coeff. of oxidized species ( a = gamma_ox * c_ox )
%   gamma_red .. activity coeff. of reduced species ( a = gamma_red * c_red )
%   E0 .. standard potential of mediator in mV (300)
%   U .. voltage applied to electrodes in mV (400)
%   t_sim .. simulation time in s (5)
%   t_record .. time points at which concentration data is to be stored in s ([0 1 2.4 3])
%   vStepTime .. time at which the voltage on electrodes steps to U in s (0.01)
%   dt_max .. maximum time increment during calculation in s (0.1)
%   dr_max .. maximum length increment during calculation in m (1)



% The calculation scheme is derived from the simslit program of Mr.
% Neudeck.
%
% Conventions:
% all values are converted into SI-units before start of calculation
% r-axis radius of whole disk (including electrode and non-electrode areas)
% phi-axis angle around z-axis
% z-axis heigth of channel (=distance of AE)
%
% !!! remember !!! : in Matlab the indexing convention is A(r,z), that is
% if you like your colums to be r and your rows to be z.
% ===> correct is i.e. c_old(i,j)

%%%%%%%%%%%%%%%%%
%%% CONSTANTS %%%
R=8.31451;                    % molar gas constant    [R] = A V s / mol / K
F=96485.309;                  % faraday constant      [F] = A s / mol
T=294.15;                     % temperature           [T] = K
FRT = F/R/T;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%% OPTIONS DIALOGS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% analyte input no
analyte_yes_no = 0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%% INPUT VARIABLES %%%%%%%%%%
%%%%%%%%%%%%%%%%
%%% GEOMETRY %%%
% prompt = {'Electrode distance:',...
%         'Number of electrodes:',...
%         'Start radii of electrodes (in m)',...
%         'End radii of electrodes (in m)',...
%         'Radius of whole disk (in m)',...
%         'Effective area correction (based on roughness)'};
% dlg_title = 'Geometry input';
% num_lines = 1;
% def     = {'10','2','[0 500]','[300 700]','1200','1'};
% answer  = inputdlg(prompt,dlg_title,num_lines,def);

% retrieve values from answer cell
% d = str2num(answer{1})*1e-6;           % electrode distance [d] = m  (=z)
d = d_ * 1e-6;
z_size = d;                             % diffusion layer width in m
% nAE = str2num(answer{2});               % number of working electrodes
% r_electrode = str2num(answer{3})/100000; % start of electrode in m
r_electrode = r_electrode_ * 1e-6;
% R_electrode = str2num(answer{4})/100000; % end of electrode in m
R_electrode = R_electrode_ * 1e-6;
% R_total = str2num(answer{5})/100000;           % length (of channel) of calculation area in m
R_total = R_total_ * 1e-6;
% free answer
% clear answer;

% %%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%% CHEMICAL PROPERTIES %%%
% % only for analyte
% if analyte_yes_no == 1
%     prompt = {'Diffuion coeff. of membrane (in cm/s):',...
%         'Analyte concentration (in mol/l)' };
%     dlg_title = 'Chemical properties...';
%     num_lines = 1;
%     def     = {'1e-6','1e-6'};
%     answer  = inputdlg(prompt,dlg_title,num_lines,def);
%     % retrieve values from answer
%     D_m = str2num(answer{1});       % diffusion coeff of membrane for the analyte in cm/s
%     c_analyt = str2num(answer{2}); % concentration of the external analyte in mol/l
%     P = D_m/b;
%     clear answer;
% end;


% general chem. properties
% prompt = {'Bulk concentration (in mol/l)',...
%         'Concentration factor ( Ox/Red )',...
%         'Diffision coeff. of redoxmediator (in cm/s)' };
% dlg_title = 'Chemical properties...';
% num_lines = 1;
% def     = {'1e-1','1/10000','0.7e-5'};
% answer  = inputdlg(prompt,dlg_title,num_lines,def);

% retrieve values from answer cell
% c_bulk = str2num(answer{1});        % concentration species A+B [c] = mol/m
c_bulk = c_bulk_ * 1e+3;
% ox_red = str2num(answer{2});        % relative concentration c_ox/c_red
c_0 = ox_red * c_bulk/(1+ox_red);     % concentration in bulk outside the calculation area
% D = str2num(answer{3}) * 1e-4;      % diffusion constant    [D] = m / s
D = D_ * 1e-4;
% % D_ox = 0.65e-5;0.71e-5
% % D_red = 0.76e-5;
% charge_transfered = str2num(answer{4});
zFRT = FRT * charge;
% gamma_ox = str2num(answer{5});
% gamma_red = str2num(answer{6});
g = gamma_ox / gamma_red;
% free answer
% clear answer;

% if ox_red is larger than 1, the simulated component is the majority component
% thus the analyte intake has to be subtracted from it, as we assume that the
% analyte will always react with the minority component
if ox_red > 1
    analyte_yes_no = -1 * analyte_yes_no;
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% VOLTAGES and POTENTIALS %%%
% prompt = {'Standardpotential E0 (in mV)',...
%         'Applied voltage (in mV)'};
% dlg_title = 'Electrical properties...';
% num_lines = 1;
% def     = {'300','400'};
% answer  = inputdlg(prompt,dlg_title,num_lines,def);

% retrieve values from answer cell
% E0 = str2num(answer{1})*1e-3;       % standard potential in V
E0 = E0_ * 1e-3;
% U  = str2num(answer{2})*1e-3;       % standard potential in V
U = U_  * 1e-3;
% % free answer
% clear answer;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% DETERMINE START POTENTIALS %%%
if ox_red == 0 
    E_eq = E0-0.3;
else
    E_eq = E0 + 1/zFRT*log(g*ox_red);
end
E_step = 0.001;

%%%%%%%%%%%%%%%%%%%%%%%%%
%%% SOLVER PROPERTIES %%%
% prompt = {'Simulation time (in s)',...
%         'Automatically limit simulation time? (y/n)',...
%         'Voltage step time (in s)',...
%         'Minimum number of grid points in z-direction',...
%         'Maximum time increment (in s)',...
%         'Maximum length increment (in m)',...
%         'Lambda (stability coeff.)'};
% dlg_title = 'Electrical properties...';
% num_lines = 1;
% def     = {'3','y','0.001','10','0.1','1','0.24'};
% answer  = inputdlg(prompt,dlg_title,num_lines,def);

% retrieve values from answer cell
% t_sim = str2num(answer{1});         % simulation time in s
% t_limit = answer{2};                % auto limit on calculation steps
t_limit = 'y';
% vStepTime = str2num(answer{3});     % voltage step time in s
% geom_step_min = str2num(answer{4});  % minimum number of geometry points
geom_step_min = 10;
% dt_max = str2num(answer{5});        % maximum time increment in s
% dr_max = str2num(answer{6})*1e-6;   % maximum length increment in m
dr_max = dr_max_ * 1e-6;
% lambda = str2num(answer{7});        % should be smaller than 0.25 to ensure stability
lambda = 0.24;
% % free answer
% clear answer;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% determine grid and initialize variables %%%
%%%%%%%%%%%%%%%%%%%%%%%
%%% CALCULATE  GRID %%%
% the used algorithm should provide a good balance between number of points for
% small geometries and accuracy (maximum increment) for large geometries
% calculate dy using minimum number of geometrie points
dz = z_size/(geom_step_min);
% limit to maximum increment
if dz > dr_max
    dz = dr_max;
end;
% calculate dr using minimum number of geometrie points
dr = R_total/(geom_step_min);
% limit to maximum increment
if dr > dr_max
    dr = dr_max;
end;
% we use same increments in r and y direction, so we will use the smaller of both
if dr > dz
    dr = dz;
else
    dz = dr;
end;
% determine number of layers and round them towards infinity
n_layers_r = ceil(R_total / dr);
n_layers_z = ceil(z_size  / dz);

r_steps = n_layers_r + 1;         % number of points in r direction
z_steps = n_layers_z + 1;         % number of points in z direction

r = dr * (0:n_layers_r);
z = dz * (0:n_layers_z);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% CALCULATE ELECTRODE VECTORS %%%
% create an area array for easier computation of currents later on
% first we create an array that includes only radii covering the electrode
% areas
rAE = [];
RAE = [];
r_help = zeros(1,length(r));
for n = 1:nAE
    rAE(n) = length(r(find(r<=r_electrode(n))));
    RAE(n) = length(r(find(r<=R_electrode(n))));
    
    r_help(rAE(n):RAE(n)) = 1;
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% CALCULATE ELECTRODE AREA VECTORS %%%
% we will calculate current using areas centered on the geometry point.
% so we have to adjust the inner most and outer most area by dividing it by 2
% [A] = m
A = zeros(1,r_steps);
A(:) = pi*( (r + dr/2).*(r + dr/2) - (r - dr/2).*(r - dr/2) ).*r_help;

% half first and last electrode area elements
for n = 1:nAE
    A(rAE(n)) = pi*( (r(rAE(n)) + dr/2)^2 - r(rAE(n))^2 );
    A(RAE(n)) = pi*( r(RAE(n))^2 - (r(RAE(n)) - dr/2)^2 );
end;

% correct area size for each element with A_eff
A = A * A_eff;
A_ges = sum(A);

%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% CALCULATE TIME GRID %%%
% determine time increment from betha criterium and limit to maximum time increment
dt = lambda * dr * dr / D;
if dt > dt_max
    dt = dt_max;
end
n_step = ceil(t_sim/dt);
% limit n_step
if t_limit == 'y'
    if n_step > z_steps*r_steps
        n_step = z_steps*r_steps;
    end;
end;

% time step at which the voltage on the electrodes will step
voltage_step = ceil(vStepTime/dt);

% recalculate lambda
lambda = D * dt / dr^2;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% INITIALIZE OUTPUT TIME VARIABLES %%%
% find t_record values in time vector
t_record = ceil(t_record./dt);
% make sure there is no zero index in the array
if t_record(1) == 0
    t_record(1) = 1;
end;

t_save = zeros(1,n_step);
t_save(t_record) = 1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% INITIALIZE CONCENTRATION VARIABLES %%%
% create start concentration vectors
c_old = ox_red * c_bulk/(1+ox_red) * ones(z_steps,r_steps);
c_new = c_old;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% INITIALIZE CURRENT VARIABLES %%%
% initialize current vector
I_redox_n = [];
current = 0;
% concentration profile history
C_slit = [];
% variable to keep track of peak current
curr_max = 0;
%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% INITIALIZE COUNTERS %%%
% we need two counter arrays for calculating in z and r direction
% for this we will use j and i respectively
j_  = 1:r_steps;             % includes all points
jj_ = 2:(r_steps-1);         % includes all but the outer most points (boundaries)
i_  = 1:z_steps;
ii_ = 2:(z_steps-1);
% boundary with electrode area (create array with all electrode indexes)
electrode_ = [];
for n = 1:nAE
    electrode_  = [electrode_ rAE(n):RAE(n)];
end;
% boundary without electrode area, exclusive the last value wich has
% to be calculated differently as it is a corner
inert_ = [];
if rAE(1) > 1
    inert_ = [2:(rAE(1)-1)];
    for n = 2:nAE
        inert_ = [inert_ (RAE(n-1)+1):(rAE(n)-1)];
    end;
    inert_ = [inert_ (RAE(nAE)+1):(r_steps-1)];
else
    for n = 2:nAE
        inert_ = [inert_ (RAE(n-1)+1):(rAE(n)-1)];
    end;
    inert_ = [inert_ (RAE(nAE)+1):(r_steps-1)];
end;

% display a wait bar to indicate calculation progress
h_waitbar = waitbar(0,'Fortschritt');

% % initialize electrode potentials
% E1_n = [];
% E2_n = [];
% % initialize equilibrium potential
% E_eq_n = [];
% % initialize ox_red relative concentration
% ox_red_n = [];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% START MAIN CALCULATION %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for l = 1:(n_step)
   %%%%%%%%%%%%%%%%%%%%%%%%%
   %%% CALCULATE CURRENT %%%
    % check on which electrode current will be smallest
   if l > voltage_step
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %%% calculate new electrode potentials %%%
        %%% these values are not needed for further calculation
        %%% and are kept only for recording/testing purposes
%         c_ox_mean = mean(mean(c_old));
%         ox_red = c_ox_mean / (c_bulk - c_ox_mean);
%         E_eq=E0 + R*T/F*log(ox_red);
        
        K = sum( A.*(c_old(2,:) + c_old(z_steps-1,:)) ) / A_ges / c_bulk;
        % with g = gamma_ox/gamma_red
        E2 = (zFRT*E0-log(-1/2*(-1-exp(zFRT*U)+K+K*exp(zFRT*U)-(1+2*exp(zFRT*U)-2*K+4*K*exp(zFRT*U)+(exp(zFRT*U))^2-2*K*(exp(zFRT*U))^2+K^2-2*K^2*exp(zFRT*U)+K^2*(exp(zFRT*U))^2)^(1/2))/(K*exp(zFRT*U)*g)))/zFRT;
        E1 = E2 - U;
%         % record electrode potentials
%         E1_1_ = [E1_ E1];
%         E2_1_ = [E2_ E2];
      Ei_1 = E1;
      Ei_2 = E2;
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      %%%%%%%% dimensionless potential xi on electrode I %%%%%%%%
      xi = (zFRT * (Ei_1 - E0));
      % nernst charge transfer on boundary I
      c_old(1,electrode_) = c_bulk * exp(xi)/(g+exp(xi));
      c_new(1,electrode_) = c_old(1,electrode_);
    
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      %%%% potential step and dimensionless potential on electrode II %%%%
      xi = (zFRT * (Ei_2 - E0));
      % nernst charge transfer on boundary II
      c_old(z_steps,electrode_) = c_bulk * exp(xi)/(g+exp(xi));
      c_new(z_steps,electrode_) = c_old(z_steps,electrode_);
    
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      %%%%%%%%%%%%%%  calculate resulting currents  %%%%%%%%%%%%%%%%%%%%%%
      % @ z = 0:
      % assuming tendency to uniform surface potential/concentration
      current = F*D/dz*sum(A .* (c_new(2,:) - c_new(1,:)));
      % @ z = max:
      % current on other electrode should be of same value
%        current2 = -F*D/dz*sum(A .* (c_new(z_steps,:) - c_new(z_steps-1,:)));

%       %%% record electrode potentials %%%
%       E1_n = [E1_n E1];
%       E2_n = [E2_n E2];
%       %%% record equilibrium potential %%%
%       E_eq_n = [E_eq_n E_eq];
%       %%% record ox_red relative concentration %%%
%       ox_red_n = [ox_red_n ox_red];
    
      % calculate dimensionless current
      %current = current / (F*A_electrode*c_bulk*sqrt(F*E_step/t_step*D/R/T));
    end;
  
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% record current value %%%
    I_redox_n = [I_redox_n current];
      
    % record peak current
    if current > curr_max
        curr_max = current;
    end;
    % record equilibrium potential
%     E_eq_n = [E_eq_n E_eq];
    % record ox_red relative concentration
%     ox_red_n = [ox_red_n ox_red];
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%%%%%%%%%%%%% CALCULATE DIFFUSION  %%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%%%%%  BOUNDARY I and II  %%%%%%
    % first calculate for the inert part of the boundaries in r direction
    % calculate CORNER POINTS (I-II) and (II-III) at r = 1 only if there is no electrode!!!
    if rAE(1) > 1
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %%% CORNER (I-II): boundary at z = 0 (least index in matlab is 1!!!)
        c_new(1,1) = c_old(1,1) + lambda*( -4*c_old(1,1) + 2*c_old(1,2) + 2*c_old(2,1) );
        %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
        %%% CORNER (II-III): boundary at z = max
        c_new(z_steps,1) = c_old(z_steps,1) + lambda*( 2*c_old(z_steps-1,1) - 4*c_old(z_steps,1) + 2*c_old(z_steps,2) );
    end;
    
    % inert_ holds all points without electrode exclusive corner points
    for j = inert_
        %%%%%%%%%%%%%%%%%%
        %%% BOUNDARY I %%%
        % boundary at z = 0 (least index in matlab is 1!!!)
        c_new(1,j) = c_old(1,j) + lambda*(dr/2/r(j)*( c_old(1,j+1) - c_old(1,j-1) ) + c_old(1,j-1) - 4*c_old(1,j) + c_old(1,j+1) + 2*c_old(2,j) );
        %%%%%%%%%%%%%%%%%%%
        %%% BOUNDARY II %%%
        % boundary at z = max
        c_new(z_steps,j) = c_old(z_steps,j) + lambda*(dr/2/r(j)*( c_old(z_steps,j+1) - c_old(z_steps,j-1) ) + c_old(z_steps,j-1) + 2*c_old(z_steps-1,j) - 4*c_old(z_steps,j) + c_old(z_steps,j+1) );        
    end;

    % calculate CORNER POINTS at r = max
    %%%%%%%%%%%%%%%%%%%%%%%%%
    %%% CORNER (I-IV): boundary at z = 0 (least index in matlab is 1!!!)
    c_new(1,r_steps) = c_old(1,r_steps) + lambda*(dr/2/r(r_steps)*( c_0 - c_old(1,r_steps-1) ) + c_old(1,r_steps-1) - 4*c_old(1,r_steps) + c_0 + 2*c_old(2,r_steps) );
    %%%%%%%%%%%%%%%%%%%%%%%%%
    %%% CORNER (II-IV): boundary at z = max
    c_new(z_steps,r_steps) = c_old(z_steps,r_steps) + lambda*(dr/2/r(r_steps)*( c_0 - c_old(z_steps,r_steps-1) ) + c_old(z_steps,r_steps-1) + 2*c_old(z_steps-1,r_steps) - 4*c_old(z_steps,r_steps) + c_0 );
    
    % loop through all layers in z direction with exeption of boundaries, which
    % have been treated already
    % calculate first element in r direction, if neccessary include boundary
    % condition here or inside loop
    %%%%%%%%%%%%%%%%%%%%
    %%% BOUNDARY III %%%
    % symmetry axis
    c_new(ii_,1) = c_old(ii_,1) + lambda*( c_old(ii_-1,1) - 4*c_old(ii_,1) + 2*c_old(ii_,2) + c_old(ii_+1,1) );
    for ii = ii_
        % calculate first element in r direction, if neccessary include boundary 1
        % condition here or before looping
        % loop through all points in r direction with exception of boundaries
        for jj = jj_
            %%%%%%%%%%%%%%%%%%
            %%% MAIN AREA: %%%
            c_new(ii,jj) = c_old(ii,jj) + lambda*( dr/2/r(jj)*( c_old(ii,jj+1) - c_old(ii,jj-1) ) + c_old(ii-1,jj) + c_old(ii,jj-1) - 4*c_old(ii,jj) + c_old(ii+1,jj) + c_old(ii,jj+1) );
        end;
        % calculate last element in r direction, if neccessary include boundary 2
        % condition here or before looping
    end;
    % calculate last element in r direction, if neccessary include boundary
    % condition here or inside loop
    %%%%%%%%%%%%%%%%%%
    %%% BOUNDARY IV %%%
    % steady concentration on bulk interface
    c_new(ii_,r_steps) = c_old(ii_,r_steps) + lambda*(dr/2*( c_0 - c_old(ii_,r_steps-1) )./r(jj) + c_old(ii_-1,r_steps) + c_old(ii_,r_steps-1) - 4*c_old(ii_,r_steps) + c_old(ii_+1,r_steps) + c_0 );

    c_old = c_new;

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% SAVE CONCENTRATION VALUES OVER TIME %%%
    if t_save(l) == 1
        % concatenate new concentration profile to history
        C_slit = cat(3,C_slit,c_new);
    end;
    % save last profile in C_end
    if l >= n_step
        C_end = c_new;
    end;
    
    % advance progress bar
    waitbar(l/(n_step+1),h_waitbar);
end;
%%%    END OF MAIN CALCULATION    %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%  output results  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% % create named plot windows
% scrsz = get(0,'ScreenSize');
% scrsz(4) = (scrsz(4));
% height=0.8*scrsz(4)/2;
% fig_display2 = figure('name','concentration profile'            ,'Position',[1          60                  scrsz(3)/2 height]);
% fig_display3 = figure('name','concentration profile at end time','Position',[scrsz(3)/2 60                  scrsz(3)/2 height]);
% % fig_control  = figure('name','control'                        ,'Position',[1          scrsz(4)/2+1 scrsz(3)/2 height]);
% fig_display1 = figure('name','current over time'                ,'Position',[scrsz(3)/2 scrsz(4)/2+1        scrsz(3)/2 height]);
% 
% % plot current over time
% figure(fig_display1);
t = dt * (0:n_step-1);
% plot(t,I_redox_n,'red');
% text(0.7*t(n_step),curr_max,['I_{end}  = ' num2str(I_redox_n(n_step)) ' A' 10 'd      = ' num2str(1e6*d) ' m' 10 'A_{AE} = ' num2str(sum(1e4*A)) ' cm'],'HorizontalAlignment','left','VerticalAlignment','top');
% xlabel('Zeit t/s');
% ylabel('Strom I/A');
% title('Strom in der Kapillarspaltzelle');
% 
% % plot concentration profile as contour plot
% figure(fig_display2);
% [C,h,CF] = contourf(10000*r,10000*z,C_end,61);
% set(h(:),'EdgeColor','none');
% colorbar;
% 
% % plot the concentration profile over time using 3d graphics
% figure(fig_display3);
% % mesh_c_red = mesh(10000*z,t,C_red);
% % mesh_c_red = mesh(10000*r,10000*z,c_bulk-C_end);
% mesh_c_red = mesh(10000*r,10000*z,C_end);
% % set fac color to interpolated data points
% set(mesh_c_red,'FaceColor','interp');
% set(mesh_c_red,'EdgeColor','interp');
% set(mesh_c_red,'FaceLighting','phong');
% set(mesh_c_red,'EdgeLighting','phong');
% title('Konzentrationsverteilung C_{red} ber Zeit und Ort im Kapillarspalt');
% ylabel('Ort im Spalt d in m');
% xlabel('Ort im Spalt r in m');
% zlabel('Konzentration c_{red} in mol/m');


close(h_waitbar);

